Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(137)

Unified Diff: src/compiler/access-builder.h

Issue 1406113007: Merge GlobalObject with JSGlobalObject. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/compiler.h ('k') | src/compiler/access-builder.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/compiler/access-builder.h
diff --git a/src/compiler/access-builder.h b/src/compiler/access-builder.h
index 048891b1310ff705ccca69210498ea472a7b6284..e8acad4839e6010431d9f741b36db83f31c9cecf 100644
--- a/src/compiler/access-builder.h
+++ b/src/compiler/access-builder.h
@@ -64,11 +64,11 @@ class AccessBuilder final : public AllStatic {
// Provides access to String::length() field.
static FieldAccess ForStringLength();
- // Provides access to GlobalObject::global_proxy() field.
- static FieldAccess ForGlobalObjectGlobalProxy();
+ // Provides access to JSGlobalObject::global_proxy() field.
+ static FieldAccess ForJSGlobalObjectGlobalProxy();
- // Provides access to GlobalObject::native_context() field.
- static FieldAccess ForGlobalObjectNativeContext();
+ // Provides access to JSGlobalObject::native_context() field.
+ static FieldAccess ForJSGlobalObjectNativeContext();
// Provides access to JSValue::value() field.
static FieldAccess ForValue();
« no previous file with comments | « src/compiler.h ('k') | src/compiler/access-builder.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698